@@ -25,74 +25,74 @@ else:
 
 __all__ = (
     "ActionParameterTypeDef",
-    "ActionSummaryTypeDef",
     "ActionTargetTypeDef",
-    "ActionTypeDef",
     "CreateExperimentTemplateActionInputTypeDef",
-    "CreateExperimentTemplateLogConfigurationInputTypeDef",
-    "CreateExperimentTemplateRequestRequestTypeDef",
-    "CreateExperimentTemplateResponseTypeDef",
+    "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef",
+    "ExperimentTemplateS3LogConfigurationInputTypeDef",
     "CreateExperimentTemplateStopConditionInputTypeDef",
-    "CreateExperimentTemplateTargetInputTypeDef",
+    "ResponseMetadataTypeDef",
+    "ExperimentTemplateTargetInputFilterTypeDef",
     "DeleteExperimentTemplateRequestRequestTypeDef",
-    "DeleteExperimentTemplateResponseTypeDef",
     "ExperimentActionStateTypeDef",
-    "ExperimentActionTypeDef",
     "ExperimentCloudWatchLogsLogConfigurationTypeDef",
-    "ExperimentLogConfigurationTypeDef",
     "ExperimentS3LogConfigurationTypeDef",
     "ExperimentStateTypeDef",
     "ExperimentStopConditionTypeDef",
-    "ExperimentSummaryTypeDef",
     "ExperimentTargetFilterTypeDef",
-    "ExperimentTargetTypeDef",
     "ExperimentTemplateActionTypeDef",
-    "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef",
     "ExperimentTemplateCloudWatchLogsLogConfigurationTypeDef",
-    "ExperimentTemplateLogConfigurationTypeDef",
-    "ExperimentTemplateS3LogConfigurationInputTypeDef",
     "ExperimentTemplateS3LogConfigurationTypeDef",
     "ExperimentTemplateStopConditionTypeDef",
     "ExperimentTemplateSummaryTypeDef",
     "ExperimentTemplateTargetFilterTypeDef",
-    "ExperimentTemplateTargetInputFilterTypeDef",
-    "ExperimentTemplateTargetTypeDef",
-    "ExperimentTemplateTypeDef",
-    "ExperimentTypeDef",
     "GetActionRequestRequestTypeDef",
-    "GetActionResponseTypeDef",
     "GetExperimentRequestRequestTypeDef",
-    "GetExperimentResponseTypeDef",
     "GetExperimentTemplateRequestRequestTypeDef",
-    "GetExperimentTemplateResponseTypeDef",
     "GetTargetResourceTypeRequestRequestTypeDef",
-    "GetTargetResourceTypeResponseTypeDef",
     "ListActionsRequestRequestTypeDef",
-    "ListActionsResponseTypeDef",
     "ListExperimentTemplatesRequestRequestTypeDef",
-    "ListExperimentTemplatesResponseTypeDef",
     "ListExperimentsRequestRequestTypeDef",
-    "ListExperimentsResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
     "ListTargetResourceTypesRequestRequestTypeDef",
-    "ListTargetResourceTypesResponseTypeDef",
-    "ResponseMetadataTypeDef",
+    "TargetResourceTypeSummaryTypeDef",
     "StartExperimentRequestRequestTypeDef",
-    "StartExperimentResponseTypeDef",
     "StopExperimentRequestRequestTypeDef",
-    "StopExperimentResponseTypeDef",
     "TagResourceRequestRequestTypeDef",
     "TargetResourceTypeParameterTypeDef",
-    "TargetResourceTypeSummaryTypeDef",
-    "TargetResourceTypeTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateExperimentTemplateActionInputItemTypeDef",
-    "UpdateExperimentTemplateLogConfigurationInputTypeDef",
-    "UpdateExperimentTemplateRequestRequestTypeDef",
-    "UpdateExperimentTemplateResponseTypeDef",
     "UpdateExperimentTemplateStopConditionInputTypeDef",
+    "ActionSummaryTypeDef",
+    "ActionTypeDef",
+    "CreateExperimentTemplateLogConfigurationInputTypeDef",
+    "UpdateExperimentTemplateLogConfigurationInputTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "CreateExperimentTemplateTargetInputTypeDef",
     "UpdateExperimentTemplateTargetInputTypeDef",
+    "ExperimentActionTypeDef",
+    "ExperimentLogConfigurationTypeDef",
+    "ExperimentSummaryTypeDef",
+    "ExperimentTargetTypeDef",
+    "ExperimentTemplateLogConfigurationTypeDef",
+    "ListExperimentTemplatesResponseTypeDef",
+    "ExperimentTemplateTargetTypeDef",
+    "ListTargetResourceTypesResponseTypeDef",
+    "TargetResourceTypeTypeDef",
+    "ListActionsResponseTypeDef",
+    "GetActionResponseTypeDef",
+    "CreateExperimentTemplateRequestRequestTypeDef",
+    "UpdateExperimentTemplateRequestRequestTypeDef",
+    "ListExperimentsResponseTypeDef",
+    "ExperimentTypeDef",
+    "ExperimentTemplateTypeDef",
+    "GetTargetResourceTypeResponseTypeDef",
+    "GetExperimentResponseTypeDef",
+    "StartExperimentResponseTypeDef",
+    "StopExperimentResponseTypeDef",
+    "CreateExperimentTemplateResponseTypeDef",
+    "DeleteExperimentTemplateResponseTypeDef",
+    "GetExperimentTemplateResponseTypeDef",
+    "UpdateExperimentTemplateResponseTypeDef",
 )
 
 ActionParameterTypeDef = TypedDict(
@@ -104,17 +104,6 @@ ActionParameterTypeDef = TypedDict(
     total=False,
 )
 
-ActionSummaryTypeDef = TypedDict(
-    "ActionSummaryTypeDef",
-    {
-        "id": str,
-        "description": str,
-        "targets": Dict[str, "ActionTargetTypeDef"],
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
 ActionTargetTypeDef = TypedDict(
     "ActionTargetTypeDef",
     {
@@ -123,18 +112,6 @@ ActionTargetTypeDef = TypedDict(
     total=False,
 )
 
-ActionTypeDef = TypedDict(
-    "ActionTypeDef",
-    {
-        "id": str,
-        "description": str,
-        "parameters": Dict[str, "ActionParameterTypeDef"],
-        "targets": Dict[str, "ActionTargetTypeDef"],
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
 _RequiredCreateExperimentTemplateActionInputTypeDef = TypedDict(
     "_RequiredCreateExperimentTemplateActionInputTypeDef",
     {
@@ -160,67 +137,35 @@ class CreateExperimentTemplateActionInputTypeDef(
     pass
 
 
-_RequiredCreateExperimentTemplateLogConfigurationInputTypeDef = TypedDict(
-    "_RequiredCreateExperimentTemplateLogConfigurationInputTypeDef",
+ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef = TypedDict(
+    "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef",
     {
-        "logSchemaVersion": int,
+        "logGroupArn": str,
     },
 )
-_OptionalCreateExperimentTemplateLogConfigurationInputTypeDef = TypedDict(
-    "_OptionalCreateExperimentTemplateLogConfigurationInputTypeDef",
+
+_RequiredExperimentTemplateS3LogConfigurationInputTypeDef = TypedDict(
+    "_RequiredExperimentTemplateS3LogConfigurationInputTypeDef",
     {
-        "cloudWatchLogsConfiguration": (
-            "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef"
-        ),
-        "s3Configuration": "ExperimentTemplateS3LogConfigurationInputTypeDef",
+        "bucketName": str,
+    },
+)
+_OptionalExperimentTemplateS3LogConfigurationInputTypeDef = TypedDict(
+    "_OptionalExperimentTemplateS3LogConfigurationInputTypeDef",
+    {
+        "prefix": str,
     },
     total=False,
 )
 
 
-class CreateExperimentTemplateLogConfigurationInputTypeDef(
-    _RequiredCreateExperimentTemplateLogConfigurationInputTypeDef,
-    _OptionalCreateExperimentTemplateLogConfigurationInputTypeDef,
+class ExperimentTemplateS3LogConfigurationInputTypeDef(
+    _RequiredExperimentTemplateS3LogConfigurationInputTypeDef,
+    _OptionalExperimentTemplateS3LogConfigurationInputTypeDef,
 ):
     pass
 
 
-_RequiredCreateExperimentTemplateRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateExperimentTemplateRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "description": str,
-        "stopConditions": Sequence["CreateExperimentTemplateStopConditionInputTypeDef"],
-        "actions": Mapping[str, "CreateExperimentTemplateActionInputTypeDef"],
-        "roleArn": str,
-    },
-)
-_OptionalCreateExperimentTemplateRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateExperimentTemplateRequestRequestTypeDef",
-    {
-        "targets": Mapping[str, "CreateExperimentTemplateTargetInputTypeDef"],
-        "tags": Mapping[str, str],
-        "logConfiguration": "CreateExperimentTemplateLogConfigurationInputTypeDef",
-    },
-    total=False,
-)
-
-
-class CreateExperimentTemplateRequestRequestTypeDef(
-    _RequiredCreateExperimentTemplateRequestRequestTypeDef,
-    _OptionalCreateExperimentTemplateRequestRequestTypeDef,
-):
-    pass
-
-
-CreateExperimentTemplateResponseTypeDef = TypedDict(
-    "CreateExperimentTemplateResponseTypeDef",
-    {
-        "experimentTemplate": "ExperimentTemplateTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredCreateExperimentTemplateStopConditionInputTypeDef = TypedDict(
     "_RequiredCreateExperimentTemplateStopConditionInputTypeDef",
     {
@@ -243,32 +188,25 @@ class CreateExperimentTemplateStopConditionInputTypeDef(
     pass
 
 
-_RequiredCreateExperimentTemplateTargetInputTypeDef = TypedDict(
-    "_RequiredCreateExperimentTemplateTargetInputTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "resourceType": str,
-        "selectionMode": str,
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
-_OptionalCreateExperimentTemplateTargetInputTypeDef = TypedDict(
-    "_OptionalCreateExperimentTemplateTargetInputTypeDef",
+
+ExperimentTemplateTargetInputFilterTypeDef = TypedDict(
+    "ExperimentTemplateTargetInputFilterTypeDef",
     {
-        "resourceArns": Sequence[str],
-        "resourceTags": Mapping[str, str],
-        "filters": Sequence["ExperimentTemplateTargetInputFilterTypeDef"],
-        "parameters": Mapping[str, str],
+        "path": str,
+        "values": Sequence[str],
     },
-    total=False,
 )
 
-
-class CreateExperimentTemplateTargetInputTypeDef(
-    _RequiredCreateExperimentTemplateTargetInputTypeDef,
-    _OptionalCreateExperimentTemplateTargetInputTypeDef,
-):
-    pass
-
-
 DeleteExperimentTemplateRequestRequestTypeDef = TypedDict(
     "DeleteExperimentTemplateRequestRequestTypeDef",
     {
@@ -276,14 +214,6 @@ DeleteExperimentTemplateRequestRequestTypeDef = TypedDict(
     },
 )
 
-DeleteExperimentTemplateResponseTypeDef = TypedDict(
-    "DeleteExperimentTemplateResponseTypeDef",
-    {
-        "experimentTemplate": "ExperimentTemplateTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ExperimentActionStateTypeDef = TypedDict(
     "ExperimentActionStateTypeDef",
     {
@@ -293,21 +223,6 @@ ExperimentActionStateTypeDef = TypedDict(
     total=False,
 )
 
-ExperimentActionTypeDef = TypedDict(
-    "ExperimentActionTypeDef",
-    {
-        "actionId": str,
-        "description": str,
-        "parameters": Dict[str, str],
-        "targets": Dict[str, str],
-        "startAfter": List[str],
-        "state": "ExperimentActionStateTypeDef",
-        "startTime": datetime,
-        "endTime": datetime,
-    },
-    total=False,
-)
-
 ExperimentCloudWatchLogsLogConfigurationTypeDef = TypedDict(
     "ExperimentCloudWatchLogsLogConfigurationTypeDef",
     {
@@ -316,16 +231,6 @@ ExperimentCloudWatchLogsLogConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-ExperimentLogConfigurationTypeDef = TypedDict(
-    "ExperimentLogConfigurationTypeDef",
-    {
-        "cloudWatchLogsConfiguration": "ExperimentCloudWatchLogsLogConfigurationTypeDef",
-        "s3Configuration": "ExperimentS3LogConfigurationTypeDef",
-        "logSchemaVersion": int,
-    },
-    total=False,
-)
-
 ExperimentS3LogConfigurationTypeDef = TypedDict(
     "ExperimentS3LogConfigurationTypeDef",
     {
@@ -353,18 +258,6 @@ ExperimentStopConditionTypeDef = TypedDict(
     total=False,
 )
 
-ExperimentSummaryTypeDef = TypedDict(
-    "ExperimentSummaryTypeDef",
-    {
-        "id": str,
-        "experimentTemplateId": str,
-        "state": "ExperimentStateTypeDef",
-        "creationTime": datetime,
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
 ExperimentTargetFilterTypeDef = TypedDict(
     "ExperimentTargetFilterTypeDef",
     {
@@ -374,19 +267,6 @@ ExperimentTargetFilterTypeDef = TypedDict(
     total=False,
 )
 
-ExperimentTargetTypeDef = TypedDict(
-    "ExperimentTargetTypeDef",
-    {
-        "resourceType": str,
-        "resourceArns": List[str],
-        "resourceTags": Dict[str, str],
-        "filters": List["ExperimentTargetFilterTypeDef"],
-        "selectionMode": str,
-        "parameters": Dict[str, str],
-    },
-    total=False,
-)
-
 ExperimentTemplateActionTypeDef = TypedDict(
     "ExperimentTemplateActionTypeDef",
     {
@@ -399,13 +279,6 @@ ExperimentTemplateActionTypeDef = TypedDict(
     total=False,
 )
 
-ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef = TypedDict(
-    "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef",
-    {
-        "logGroupArn": str,
-    },
-)
-
 ExperimentTemplateCloudWatchLogsLogConfigurationTypeDef = TypedDict(
     "ExperimentTemplateCloudWatchLogsLogConfigurationTypeDef",
     {
@@ -414,38 +287,6 @@ ExperimentTemplateCloudWatchLogsLogConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-ExperimentTemplateLogConfigurationTypeDef = TypedDict(
-    "ExperimentTemplateLogConfigurationTypeDef",
-    {
-        "cloudWatchLogsConfiguration": "ExperimentTemplateCloudWatchLogsLogConfigurationTypeDef",
-        "s3Configuration": "ExperimentTemplateS3LogConfigurationTypeDef",
-        "logSchemaVersion": int,
-    },
-    total=False,
-)
-
-_RequiredExperimentTemplateS3LogConfigurationInputTypeDef = TypedDict(
-    "_RequiredExperimentTemplateS3LogConfigurationInputTypeDef",
-    {
-        "bucketName": str,
-    },
-)
-_OptionalExperimentTemplateS3LogConfigurationInputTypeDef = TypedDict(
-    "_OptionalExperimentTemplateS3LogConfigurationInputTypeDef",
-    {
-        "prefix": str,
-    },
-    total=False,
-)
-
-
-class ExperimentTemplateS3LogConfigurationInputTypeDef(
-    _RequiredExperimentTemplateS3LogConfigurationInputTypeDef,
-    _OptionalExperimentTemplateS3LogConfigurationInputTypeDef,
-):
-    pass
-
-
 ExperimentTemplateS3LogConfigurationTypeDef = TypedDict(
     "ExperimentTemplateS3LogConfigurationTypeDef",
     {
@@ -485,63 +326,6 @@ ExperimentTemplateTargetFilterTypeDef = TypedDict(
     total=False,
 )
 
-ExperimentTemplateTargetInputFilterTypeDef = TypedDict(
-    "ExperimentTemplateTargetInputFilterTypeDef",
-    {
-        "path": str,
-        "values": Sequence[str],
-    },
-)
-
-ExperimentTemplateTargetTypeDef = TypedDict(
-    "ExperimentTemplateTargetTypeDef",
-    {
-        "resourceType": str,
-        "resourceArns": List[str],
-        "resourceTags": Dict[str, str],
-        "filters": List["ExperimentTemplateTargetFilterTypeDef"],
-        "selectionMode": str,
-        "parameters": Dict[str, str],
-    },
-    total=False,
-)
-
-ExperimentTemplateTypeDef = TypedDict(
-    "ExperimentTemplateTypeDef",
-    {
-        "id": str,
-        "description": str,
-        "targets": Dict[str, "ExperimentTemplateTargetTypeDef"],
-        "actions": Dict[str, "ExperimentTemplateActionTypeDef"],
-        "stopConditions": List["ExperimentTemplateStopConditionTypeDef"],
-        "creationTime": datetime,
-        "lastUpdateTime": datetime,
-        "roleArn": str,
-        "tags": Dict[str, str],
-        "logConfiguration": "ExperimentTemplateLogConfigurationTypeDef",
-    },
-    total=False,
-)
-
-ExperimentTypeDef = TypedDict(
-    "ExperimentTypeDef",
-    {
-        "id": str,
-        "experimentTemplateId": str,
-        "roleArn": str,
-        "state": "ExperimentStateTypeDef",
-        "targets": Dict[str, "ExperimentTargetTypeDef"],
-        "actions": Dict[str, "ExperimentActionTypeDef"],
-        "stopConditions": List["ExperimentStopConditionTypeDef"],
-        "creationTime": datetime,
-        "startTime": datetime,
-        "endTime": datetime,
-        "tags": Dict[str, str],
-        "logConfiguration": "ExperimentLogConfigurationTypeDef",
-    },
-    total=False,
-)
-
 GetActionRequestRequestTypeDef = TypedDict(
     "GetActionRequestRequestTypeDef",
     {
@@ -549,14 +333,6 @@ GetActionRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetActionResponseTypeDef = TypedDict(
-    "GetActionResponseTypeDef",
-    {
-        "action": "ActionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetExperimentRequestRequestTypeDef = TypedDict(
     "GetExperimentRequestRequestTypeDef",
     {
@@ -564,14 +340,6 @@ GetExperimentRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetExperimentResponseTypeDef = TypedDict(
-    "GetExperimentResponseTypeDef",
-    {
-        "experiment": "ExperimentTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetExperimentTemplateRequestRequestTypeDef = TypedDict(
     "GetExperimentTemplateRequestRequestTypeDef",
     {
@@ -579,14 +347,6 @@ GetExperimentTemplateRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetExperimentTemplateResponseTypeDef = TypedDict(
-    "GetExperimentTemplateResponseTypeDef",
-    {
-        "experimentTemplate": "ExperimentTemplateTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 GetTargetResourceTypeRequestRequestTypeDef = TypedDict(
     "GetTargetResourceTypeRequestRequestTypeDef",
     {
@@ -594,14 +354,6 @@ GetTargetResourceTypeRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetTargetResourceTypeResponseTypeDef = TypedDict(
-    "GetTargetResourceTypeResponseTypeDef",
-    {
-        "targetResourceType": "TargetResourceTypeTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListActionsRequestRequestTypeDef = TypedDict(
     "ListActionsRequestRequestTypeDef",
     {
@@ -611,15 +363,6 @@ ListActionsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListActionsResponseTypeDef = TypedDict(
-    "ListActionsResponseTypeDef",
-    {
-        "actions": List["ActionSummaryTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListExperimentTemplatesRequestRequestTypeDef = TypedDict(
     "ListExperimentTemplatesRequestRequestTypeDef",
     {
@@ -629,15 +372,6 @@ ListExperimentTemplatesRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListExperimentTemplatesResponseTypeDef = TypedDict(
-    "ListExperimentTemplatesResponseTypeDef",
-    {
-        "experimentTemplates": List["ExperimentTemplateSummaryTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListExperimentsRequestRequestTypeDef = TypedDict(
     "ListExperimentsRequestRequestTypeDef",
     {
@@ -647,15 +381,6 @@ ListExperimentsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListExperimentsResponseTypeDef = TypedDict(
-    "ListExperimentsResponseTypeDef",
-    {
-        "experiments": List["ExperimentSummaryTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
     "ListTagsForResourceRequestRequestTypeDef",
     {
@@ -663,14 +388,6 @@ ListTagsForResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListTargetResourceTypesRequestRequestTypeDef = TypedDict(
     "ListTargetResourceTypesRequestRequestTypeDef",
     {
@@ -680,24 +397,13 @@ ListTargetResourceTypesRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListTargetResourceTypesResponseTypeDef = TypedDict(
-    "ListTargetResourceTypesResponseTypeDef",
+TargetResourceTypeSummaryTypeDef = TypedDict(
+    "TargetResourceTypeSummaryTypeDef",
     {
-        "targetResourceTypes": List["TargetResourceTypeSummaryTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "resourceType": str,
+        "description": str,
     },
+    total=False,
 )
 
 _RequiredStartExperimentRequestRequestTypeDef = TypedDict(
@@ -722,14 +428,6 @@ class StartExperimentRequestRequestTypeDef(
     pass
 
 
-StartExperimentResponseTypeDef = TypedDict(
-    "StartExperimentResponseTypeDef",
-    {
-        "experiment": "ExperimentTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 StopExperimentRequestRequestTypeDef = TypedDict(
     "StopExperimentRequestRequestTypeDef",
     {
@@ -737,14 +435,6 @@ StopExperimentRequestRequestTypeDef = TypedDict(
     },
 )
 
-StopExperimentResponseTypeDef = TypedDict(
-    "StopExperimentResponseTypeDef",
-    {
-        "experiment": "ExperimentTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
@@ -762,25 +452,6 @@ TargetResourceTypeParameterTypeDef = TypedDict(
     total=False,
 )
 
-TargetResourceTypeSummaryTypeDef = TypedDict(
-    "TargetResourceTypeSummaryTypeDef",
-    {
-        "resourceType": str,
-        "description": str,
-    },
-    total=False,
-)
-
-TargetResourceTypeTypeDef = TypedDict(
-    "TargetResourceTypeTypeDef",
-    {
-        "resourceType": str,
-        "description": str,
-        "parameters": Dict[str, "TargetResourceTypeParameterTypeDef"],
-    },
-    total=False,
-)
-
 _RequiredUntagResourceRequestRequestTypeDef = TypedDict(
     "_RequiredUntagResourceRequestRequestTypeDef",
     {
@@ -814,53 +485,6 @@ UpdateExperimentTemplateActionInputItemTypeDef = TypedDict(
     total=False,
 )
 
-UpdateExperimentTemplateLogConfigurationInputTypeDef = TypedDict(
-    "UpdateExperimentTemplateLogConfigurationInputTypeDef",
-    {
-        "cloudWatchLogsConfiguration": (
-            "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef"
-        ),
-        "s3Configuration": "ExperimentTemplateS3LogConfigurationInputTypeDef",
-        "logSchemaVersion": int,
-    },
-    total=False,
-)
-
-_RequiredUpdateExperimentTemplateRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateExperimentTemplateRequestRequestTypeDef",
-    {
-        "id": str,
-    },
-)
-_OptionalUpdateExperimentTemplateRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateExperimentTemplateRequestRequestTypeDef",
-    {
-        "description": str,
-        "stopConditions": Sequence["UpdateExperimentTemplateStopConditionInputTypeDef"],
-        "targets": Mapping[str, "UpdateExperimentTemplateTargetInputTypeDef"],
-        "actions": Mapping[str, "UpdateExperimentTemplateActionInputItemTypeDef"],
-        "roleArn": str,
-        "logConfiguration": "UpdateExperimentTemplateLogConfigurationInputTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateExperimentTemplateRequestRequestTypeDef(
-    _RequiredUpdateExperimentTemplateRequestRequestTypeDef,
-    _OptionalUpdateExperimentTemplateRequestRequestTypeDef,
-):
-    pass
-
-
-UpdateExperimentTemplateResponseTypeDef = TypedDict(
-    "UpdateExperimentTemplateResponseTypeDef",
-    {
-        "experimentTemplate": "ExperimentTemplateTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredUpdateExperimentTemplateStopConditionInputTypeDef = TypedDict(
     "_RequiredUpdateExperimentTemplateStopConditionInputTypeDef",
     {
@@ -883,6 +507,96 @@ class UpdateExperimentTemplateStopConditionInputTypeDef(
     pass
 
 
+ActionSummaryTypeDef = TypedDict(
+    "ActionSummaryTypeDef",
+    {
+        "id": str,
+        "description": str,
+        "targets": Dict[str, ActionTargetTypeDef],
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+ActionTypeDef = TypedDict(
+    "ActionTypeDef",
+    {
+        "id": str,
+        "description": str,
+        "parameters": Dict[str, ActionParameterTypeDef],
+        "targets": Dict[str, ActionTargetTypeDef],
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+_RequiredCreateExperimentTemplateLogConfigurationInputTypeDef = TypedDict(
+    "_RequiredCreateExperimentTemplateLogConfigurationInputTypeDef",
+    {
+        "logSchemaVersion": int,
+    },
+)
+_OptionalCreateExperimentTemplateLogConfigurationInputTypeDef = TypedDict(
+    "_OptionalCreateExperimentTemplateLogConfigurationInputTypeDef",
+    {
+        "cloudWatchLogsConfiguration": ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef,
+        "s3Configuration": ExperimentTemplateS3LogConfigurationInputTypeDef,
+    },
+    total=False,
+)
+
+
+class CreateExperimentTemplateLogConfigurationInputTypeDef(
+    _RequiredCreateExperimentTemplateLogConfigurationInputTypeDef,
+    _OptionalCreateExperimentTemplateLogConfigurationInputTypeDef,
+):
+    pass
+
+
+UpdateExperimentTemplateLogConfigurationInputTypeDef = TypedDict(
+    "UpdateExperimentTemplateLogConfigurationInputTypeDef",
+    {
+        "cloudWatchLogsConfiguration": ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef,
+        "s3Configuration": ExperimentTemplateS3LogConfigurationInputTypeDef,
+        "logSchemaVersion": int,
+    },
+    total=False,
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredCreateExperimentTemplateTargetInputTypeDef = TypedDict(
+    "_RequiredCreateExperimentTemplateTargetInputTypeDef",
+    {
+        "resourceType": str,
+        "selectionMode": str,
+    },
+)
+_OptionalCreateExperimentTemplateTargetInputTypeDef = TypedDict(
+    "_OptionalCreateExperimentTemplateTargetInputTypeDef",
+    {
+        "resourceArns": Sequence[str],
+        "resourceTags": Mapping[str, str],
+        "filters": Sequence[ExperimentTemplateTargetInputFilterTypeDef],
+        "parameters": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateExperimentTemplateTargetInputTypeDef(
+    _RequiredCreateExperimentTemplateTargetInputTypeDef,
+    _OptionalCreateExperimentTemplateTargetInputTypeDef,
+):
+    pass
+
+
 _RequiredUpdateExperimentTemplateTargetInputTypeDef = TypedDict(
     "_RequiredUpdateExperimentTemplateTargetInputTypeDef",
     {
@@ -895,7 +609,7 @@ _OptionalUpdateExperimentTemplateTargetInputTypeDef = TypedDict(
     {
         "resourceArns": Sequence[str],
         "resourceTags": Mapping[str, str],
-        "filters": Sequence["ExperimentTemplateTargetInputFilterTypeDef"],
+        "filters": Sequence[ExperimentTemplateTargetInputFilterTypeDef],
         "parameters": Mapping[str, str],
     },
     total=False,
@@ -907,3 +621,286 @@ class UpdateExperimentTemplateTargetInputTypeDef(
     _OptionalUpdateExperimentTemplateTargetInputTypeDef,
 ):
     pass
+
+
+ExperimentActionTypeDef = TypedDict(
+    "ExperimentActionTypeDef",
+    {
+        "actionId": str,
+        "description": str,
+        "parameters": Dict[str, str],
+        "targets": Dict[str, str],
+        "startAfter": List[str],
+        "state": ExperimentActionStateTypeDef,
+        "startTime": datetime,
+        "endTime": datetime,
+    },
+    total=False,
+)
+
+ExperimentLogConfigurationTypeDef = TypedDict(
+    "ExperimentLogConfigurationTypeDef",
+    {
+        "cloudWatchLogsConfiguration": ExperimentCloudWatchLogsLogConfigurationTypeDef,
+        "s3Configuration": ExperimentS3LogConfigurationTypeDef,
+        "logSchemaVersion": int,
+    },
+    total=False,
+)
+
+ExperimentSummaryTypeDef = TypedDict(
+    "ExperimentSummaryTypeDef",
+    {
+        "id": str,
+        "experimentTemplateId": str,
+        "state": ExperimentStateTypeDef,
+        "creationTime": datetime,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+ExperimentTargetTypeDef = TypedDict(
+    "ExperimentTargetTypeDef",
+    {
+        "resourceType": str,
+        "resourceArns": List[str],
+        "resourceTags": Dict[str, str],
+        "filters": List[ExperimentTargetFilterTypeDef],
+        "selectionMode": str,
+        "parameters": Dict[str, str],
+    },
+    total=False,
+)
+
+ExperimentTemplateLogConfigurationTypeDef = TypedDict(
+    "ExperimentTemplateLogConfigurationTypeDef",
+    {
+        "cloudWatchLogsConfiguration": ExperimentTemplateCloudWatchLogsLogConfigurationTypeDef,
+        "s3Configuration": ExperimentTemplateS3LogConfigurationTypeDef,
+        "logSchemaVersion": int,
+    },
+    total=False,
+)
+
+ListExperimentTemplatesResponseTypeDef = TypedDict(
+    "ListExperimentTemplatesResponseTypeDef",
+    {
+        "experimentTemplates": List[ExperimentTemplateSummaryTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ExperimentTemplateTargetTypeDef = TypedDict(
+    "ExperimentTemplateTargetTypeDef",
+    {
+        "resourceType": str,
+        "resourceArns": List[str],
+        "resourceTags": Dict[str, str],
+        "filters": List[ExperimentTemplateTargetFilterTypeDef],
+        "selectionMode": str,
+        "parameters": Dict[str, str],
+    },
+    total=False,
+)
+
+ListTargetResourceTypesResponseTypeDef = TypedDict(
+    "ListTargetResourceTypesResponseTypeDef",
+    {
+        "targetResourceTypes": List[TargetResourceTypeSummaryTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+TargetResourceTypeTypeDef = TypedDict(
+    "TargetResourceTypeTypeDef",
+    {
+        "resourceType": str,
+        "description": str,
+        "parameters": Dict[str, TargetResourceTypeParameterTypeDef],
+    },
+    total=False,
+)
+
+ListActionsResponseTypeDef = TypedDict(
+    "ListActionsResponseTypeDef",
+    {
+        "actions": List[ActionSummaryTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetActionResponseTypeDef = TypedDict(
+    "GetActionResponseTypeDef",
+    {
+        "action": ActionTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredCreateExperimentTemplateRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateExperimentTemplateRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "description": str,
+        "stopConditions": Sequence[CreateExperimentTemplateStopConditionInputTypeDef],
+        "actions": Mapping[str, CreateExperimentTemplateActionInputTypeDef],
+        "roleArn": str,
+    },
+)
+_OptionalCreateExperimentTemplateRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateExperimentTemplateRequestRequestTypeDef",
+    {
+        "targets": Mapping[str, CreateExperimentTemplateTargetInputTypeDef],
+        "tags": Mapping[str, str],
+        "logConfiguration": CreateExperimentTemplateLogConfigurationInputTypeDef,
+    },
+    total=False,
+)
+
+
+class CreateExperimentTemplateRequestRequestTypeDef(
+    _RequiredCreateExperimentTemplateRequestRequestTypeDef,
+    _OptionalCreateExperimentTemplateRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredUpdateExperimentTemplateRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateExperimentTemplateRequestRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+_OptionalUpdateExperimentTemplateRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateExperimentTemplateRequestRequestTypeDef",
+    {
+        "description": str,
+        "stopConditions": Sequence[UpdateExperimentTemplateStopConditionInputTypeDef],
+        "targets": Mapping[str, UpdateExperimentTemplateTargetInputTypeDef],
+        "actions": Mapping[str, UpdateExperimentTemplateActionInputItemTypeDef],
+        "roleArn": str,
+        "logConfiguration": UpdateExperimentTemplateLogConfigurationInputTypeDef,
+    },
+    total=False,
+)
+
+
+class UpdateExperimentTemplateRequestRequestTypeDef(
+    _RequiredUpdateExperimentTemplateRequestRequestTypeDef,
+    _OptionalUpdateExperimentTemplateRequestRequestTypeDef,
+):
+    pass
+
+
+ListExperimentsResponseTypeDef = TypedDict(
+    "ListExperimentsResponseTypeDef",
+    {
+        "experiments": List[ExperimentSummaryTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ExperimentTypeDef = TypedDict(
+    "ExperimentTypeDef",
+    {
+        "id": str,
+        "experimentTemplateId": str,
+        "roleArn": str,
+        "state": ExperimentStateTypeDef,
+        "targets": Dict[str, ExperimentTargetTypeDef],
+        "actions": Dict[str, ExperimentActionTypeDef],
+        "stopConditions": List[ExperimentStopConditionTypeDef],
+        "creationTime": datetime,
+        "startTime": datetime,
+        "endTime": datetime,
+        "tags": Dict[str, str],
+        "logConfiguration": ExperimentLogConfigurationTypeDef,
+    },
+    total=False,
+)
+
+ExperimentTemplateTypeDef = TypedDict(
+    "ExperimentTemplateTypeDef",
+    {
+        "id": str,
+        "description": str,
+        "targets": Dict[str, ExperimentTemplateTargetTypeDef],
+        "actions": Dict[str, ExperimentTemplateActionTypeDef],
+        "stopConditions": List[ExperimentTemplateStopConditionTypeDef],
+        "creationTime": datetime,
+        "lastUpdateTime": datetime,
+        "roleArn": str,
+        "tags": Dict[str, str],
+        "logConfiguration": ExperimentTemplateLogConfigurationTypeDef,
+    },
+    total=False,
+)
+
+GetTargetResourceTypeResponseTypeDef = TypedDict(
+    "GetTargetResourceTypeResponseTypeDef",
+    {
+        "targetResourceType": TargetResourceTypeTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetExperimentResponseTypeDef = TypedDict(
+    "GetExperimentResponseTypeDef",
+    {
+        "experiment": ExperimentTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StartExperimentResponseTypeDef = TypedDict(
+    "StartExperimentResponseTypeDef",
+    {
+        "experiment": ExperimentTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StopExperimentResponseTypeDef = TypedDict(
+    "StopExperimentResponseTypeDef",
+    {
+        "experiment": ExperimentTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateExperimentTemplateResponseTypeDef = TypedDict(
+    "CreateExperimentTemplateResponseTypeDef",
+    {
+        "experimentTemplate": ExperimentTemplateTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DeleteExperimentTemplateResponseTypeDef = TypedDict(
+    "DeleteExperimentTemplateResponseTypeDef",
+    {
+        "experimentTemplate": ExperimentTemplateTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetExperimentTemplateResponseTypeDef = TypedDict(
+    "GetExperimentTemplateResponseTypeDef",
+    {
+        "experimentTemplate": ExperimentTemplateTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateExperimentTemplateResponseTypeDef = TypedDict(
+    "UpdateExperimentTemplateResponseTypeDef",
+    {
+        "experimentTemplate": ExperimentTemplateTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
